from .buridan import buridan
from .installation import installation
from .introduction import introduction
from ..changelog.changelog import changelog


getting_started_config = {
    "buridan": [buridan],
    "installation": [installation],
    "introduction": [introduction],
    "changelog": [changelog],
}
